import json
from cgi import parse_qs
import os
from datetime import datetime

products = {
'A001': {'name': 'Alarm Clock', 'price': 10}, 
'A002': {'name': 'Bi-Noculars', 'price': 35}}

DEVELOP_MODE = True
def debugLog(msg, must=False) :
    if not DEVELOP_MODE and not must :
        return
    dirpath = os.path.dirname(os.path.realpath(__file__))
    debugfile = "{}/log/debug.log".format(dirpath)
    with open(debugfile, 'a', encoding='utf-8') as f :
        f.write("{} {}\n".format(datetime.now().strftime("%Y-%m-%d %H:%M:%S"), msg))
        
def handle_get(environ) :
    debugLog("QUERY_STRING: {}".format(environ['QUERY_STRING']))
    qs = parse_qs(environ['QUERY_STRING'])
    debugLog("qs: {}".format(qs))
    id = qs.get('id', [''])[0]
    return { "name": products[id]['name'], "price": products[id]['price'] } 

def handle_post(environ) :    
    try:
        content_len = int(environ.get('CONTENT_LENGTH', 0))
    except :
        content_len = 0

    debugLog("content_len: {}".format(content_len), True)
    request_body = environ['wsgi.input'].read(content_len)
    debugLog("wsgi.input: {}".format(request_body))

    rlist = request_body.decode().split("\n")
    debugLog("no of lines: {}".format(len(rlist)), True)
    params = {}
    for i in range(0, len(rlist)-2, 4) :
        key = rlist[i+1].split("Content-Disposition: form-data; name=\"")[1].split("\"")[0]
        value = rlist[i+3].strip()
        params[key] = value
        
    debugLog("POST data: {}".format(params))
    id = params['id']
    return { "name": products[id]['name'], "price": products[id]['price'] } 
        
def application(environ, start_response):
    status = '200 OK'

    if environ['REQUEST_METHOD'] == 'GET' :
        rdict = handle_get(environ)
    elif environ['REQUEST_METHOD'] == 'POST' : 
        rdict = handle_post(environ)
    else :
        rdict = { "name": "", "price": 0 }

    output = bytes(json.dumps(rdict), 'utf-8')

    response_headers = [('Content-type', 'application/json'),
                        ('Content-Length', str(len(output)))]
    start_response(status, response_headers)

    return [output]
